@@ -1,9 +1,9 @@
 /***************************************************************************
- PangoGenerator.cpp  -  description
+                   PangoGenerator.cpp  -  description
                              -------------------
     begin                : Sept 5 2014
     copyright            : (C) 2014 by Dominik Schmidt
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
