@@ -44,6 +44,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindowClass), oldThemeIndex(0), getDataFromCP(false), runFirstTime(true)
 {
+
     ui->setupUi(this);
     this->setWindowTitle(QString("Highlight %1").arg( HIGHLIGHT_VERSION));
 
@@ -160,13 +161,46 @@ MainWindow::MainWindow(QWidget *parent)
 
     //avoid ugly buttons in MacOS
     #ifndef Q_OS_OSX
-        ui->pbPluginReadFilePath->setMaximumWidth(30);
-        ui->pbOutputDest->setMaximumWidth(30);
-        ui->pbHTMLChooseStyleIncFile->setMaximumWidth(30);
-        ui->pbLATEXChooseStyleIncFile->setMaximumWidth(30);
-        ui->pbTEXChooseStyleIncFile->setMaximumWidth(30);
-        ui->pbSVGChooseStyleIncFile->setMaximumWidth(30);
-        ui->tabIOSelection->setDocumentMode(false);
+    ui->pbPluginReadFilePath->setMaximumWidth(30);
+    ui->pbOutputDest->setMaximumWidth(30);
+    ui->pbHTMLChooseStyleIncFile->setMaximumWidth(30);
+    ui->pbLATEXChooseStyleIncFile->setMaximumWidth(30);
+    ui->pbTEXChooseStyleIncFile->setMaximumWidth(30);
+    ui->pbSVGChooseStyleIncFile->setMaximumWidth(30);
+    ui->tabIOSelection->setDocumentMode(false);
+    #endif
+
+    #ifdef Q_OS_WIN
+    // https://forum.qt.io/topic/101391/windows-10-dark-theme/
+    if (QSysInfo::productVersion()=="10") {
+        QSettings settings("HKEY_CURRENT_USER\\Software\\Microsoft\\Windows\\CurrentVersion\\Themes\\Personalize",QSettings::NativeFormat);
+        if(settings.value("AppsUseLightTheme")==0){
+            qApp->setStyle(QStyleFactory::create("Fusion"));
+            QPalette darkPalette;
+            QColor darkColor = QColor(45,45,45);
+            QColor disabledColor = QColor(127,127,127);
+            darkPalette.setColor(QPalette::Window, darkColor);
+            darkPalette.setColor(QPalette::WindowText, Qt::white);
+            darkPalette.setColor(QPalette::Base, QColor(18,18,18));
+            darkPalette.setColor(QPalette::AlternateBase, darkColor);
+            darkPalette.setColor(QPalette::ToolTipBase, Qt::white);
+            darkPalette.setColor(QPalette::ToolTipText, Qt::white);
+            darkPalette.setColor(QPalette::Text, Qt::white);
+            darkPalette.setColor(QPalette::Disabled, QPalette::Text, disabledColor);
+            darkPalette.setColor(QPalette::Button, darkColor);
+            darkPalette.setColor(QPalette::ButtonText, Qt::white);
+            darkPalette.setColor(QPalette::Disabled, QPalette::ButtonText, disabledColor);
+            darkPalette.setColor(QPalette::BrightText, Qt::red);
+            darkPalette.setColor(QPalette::Link, QColor(42, 130, 218));
+
+            darkPalette.setColor(QPalette::Highlight, QColor(153, 153, 153));
+            darkPalette.setColor(QPalette::HighlightedText, Qt::black);
+            darkPalette.setColor(QPalette::Disabled, QPalette::HighlightedText, disabledColor);
+
+            qApp->setPalette(darkPalette);
+            qApp->setStyleSheet("QToolTip { color: #ffffff; background-color: #404040; border: 1px solid white; }");
+        }
+    }
     #endif
 
     QObject::connect(ui->pbOpenFiles, SIGNAL(clicked()), this, SLOT(openFiles()));
@@ -1581,8 +1615,11 @@ void MainWindow::updatePreview()
 
                 QString syntaxDesc = tr("Current syntax: %1 %2").arg(QString::fromStdString(pwgenerator.getSyntaxDescription())).arg(langInfo);
                 QString themeDesc = tr("Current theme: %1 %2").arg(QString::fromStdString(pwgenerator.getThemeDescription())).arg(themeInfo);
+                float contrast = pwgenerator.getThemeContrast();
+                QString contrastLowHint(contrast<4.5 ? "!":"");
+                QString contrastDesc = tr("Contrast: %1 %2").arg(contrast, 1, 'f', 2).arg(contrastLowHint);
 
-                statusBar()->showMessage(QString("%1 | %2").arg(syntaxDesc, themeDesc));
+                statusBar()->showMessage(QString("%1 | %2 | %3").arg(syntaxDesc, themeDesc, contrastDesc));
             }
 
 
